==> veracity-source-1.0.0.10517.tar.gz: veracity/src/docs/vv-help-branch.md <==
The `branch` command has several subcommands.  These subcommands can be grouped as follows:

Group 1:
-------
Subcommands that deal with the "attached" state of the working copy.  These can only be used from within a working copy.

new BRANCHNAME
: Attach the working copy to a new branch and begin working in it.  The branch will be created with the next commit.  It is an error if BRANCHNAME already exists.
attach BRANCHNAME
: Attach the working copy to an existing branch in order to         continue, fork, or start a new instance of that branch.  BRANCHNAME will be applied starting with the next commit.  BRANCHNAME must indicate an existing branch.
detach
: Detach the working copy from any named branch.  The next commit will start an anonymous branch and will require the `--detached` option.
(none)
: `vv branch` with no subcommand displays the working copy's current branch attachment.

Group 2:
-------
Subcommands that are used for manipulating branch heads in any repository.  
If you are in a working copy they will act on the current repo, but they can act on any repository by 
using the `--repo` option.

add-head BRANCHNAME --rev CSID [--repo REPOSITORY]
:        Create a new BRANCHNAME head at CSID.  BRANCHNAME can refer to a new         or an existing branch.  BRANCHNAME's head count will be increased by         one.
remove-head BRANCHNAME --rev CSID [--rev CSID [...]] [--repo REPOSITORY]
:        Remove the BRANCHNAME head at CSID.  CSID will no longer be a head of         BRANCHNAME.  BRANCHNAME must refer to an existing branch. BRANCHNAME's        head count will be decreased by one for each specified CSID.
remove-head BRANCHNAME --all [--repo REPOSITORY]
:        Remove all BRANCHNAME heads, effectively deleting the BRANCHNAME          branch.  BRANCHNAME must refer to an existing branch.
move-head BRANCHNAME [--rev CSID1] --rev CSID2 [--repo REPOSITORY]
:        Move a head of BRANCHNAME from one changeset to another.  The CSID          that holds a BRANCHNAME head will be the source, and the CSID that         does not will be the target.  If BRANCHNAME has only one head, then         the source argument is optional.  BRANCHNAME's total head count will         be unchanged after move-head.
move-head BRANCHNAME --all --rev CSID [--repo REPOSITORY]
:       Consolidate and move all existing BRANCHNAME heads to the changeset         identified by CSID.  BRANCHNAME will be left with only one head at         CSID.

Group 3:
-------
Subcommands that act on branches as a whole.  These are used primarily for maintenance.  If you are in a working copy they will act on the current repo, but they can act on any repository with the --repo option.

close BRANCHNAME [--repo REPOSITORY]
:        Close, or de-activate, the branch referred to by BRANCHNAME.          BRANCHNAME's heads will no longer be included in a 'heads' display.         `vv branch list` will include BRANCHNAME, but it will be marked as `(closed)`.
reopen BRANCHNAME [--repo REPOSITORY]
:        Reopen, or re-activate, the branch referred to by BRANCHNAME.  All of         BRANCHNAME's heads will again be visible.
list [--all] [--repo REPOSITORY]
:        List all open branches, indicating those that need merging. If `--all` is used, then include closed branches, indicating their closed status.

==> veracity-source-1.1.0.10565.tar.gz: veracity/src/docs/vv-help-branch.md <==
The `branch` command has several subcommands.  These subcommands can be grouped as follows:

Group 1:
-------
Subcommands that deal with the "attached" state of the working copy.  These can only be used from within a working copy.

new BRANCHNAME
: Attach the working copy to a new branch and begin working in it.  The branch will be created with the next commit.  It is an error if BRANCHNAME already exists.
attach BRANCHNAME
: Attach the working copy to an existing branch in order to         continue, fork, or start a new instance of that branch.  BRANCHNAME will be applied starting with the next commit.  BRANCHNAME must indicate an existing branch.
detach
: Detach the working copy from any named branch.  The next commit will start an anonymous branch and will require the `--detached` option.
(none)
: `vv branch` with no subcommand displays the working copy's current branch attachment.

Group 2:
-------
Subcommands that are used for manipulating branch heads in any repository.  
If run from inside a working copy, they act on the current repo, but they can act on any repository by 
using the `--repo` option.

add-head BRANCHNAME --rev CSID [--repo REPOSITORY]
:        Create a new BRANCHNAME head at CSID.  BRANCHNAME can refer to a new         or an existing branch.  BRANCHNAME's head count will be increased by         one.
remove-head BRANCHNAME --rev CSID [--rev CSID [...]] [--repo REPOSITORY]
:        Remove the BRANCHNAME head at CSID.  CSID will no longer be a head of         BRANCHNAME.  BRANCHNAME must refer to an existing branch. BRANCHNAME's        head count will be decreased by one for each specified CSID.
remove-head BRANCHNAME --all [--repo REPOSITORY]
:        Remove all BRANCHNAME heads, effectively deleting the BRANCHNAME          branch.  BRANCHNAME must refer to an existing branch.
move-head BRANCHNAME [--rev CSID1] --rev CSID2 [--repo REPOSITORY]
:        Move a head of BRANCHNAME from one changeset to another.  The CSID          that holds a BRANCHNAME head will be the source, and the CSID that         does not will be the target.  If BRANCHNAME has only one head, then         the source argument is optional.  BRANCHNAME's total head count will         be unchanged after move-head.
move-head BRANCHNAME --all --rev CSID [--repo REPOSITORY]
:       Consolidate and move all existing BRANCHNAME heads to the changeset         identified by CSID.  BRANCHNAME will be left with only one head at         CSID.

Group 3:
-------
Subcommands that act on branches as a whole.  These are used primarily for maintenance.  If run from inside a working copy, they act on the current repo, but they can act on any repository with the --repo option.

close BRANCHNAME [--repo REPOSITORY]
:        Close, or de-activate, the branch referred to by BRANCHNAME.          BRANCHNAME's heads will no longer be included in a 'heads' display.         `vv branch list` will include BRANCHNAME, but it will be marked as `(closed)`.
reopen BRANCHNAME [--repo REPOSITORY]
:        Reopen, or re-activate, the branch referred to by BRANCHNAME.  All of         BRANCHNAME's heads will again be visible.
list [--all] [--repo REPOSITORY]
:        List all open branches, indicating those that need merging. If `--all` is used, then include closed branches, indicating their closed status.
